==> tesseract_olap-0.6.0-py3-none-any.whl: tesseract_olap/backend/clickhouse/dialect.py <==
from enum import Enum
from typing import Union

from pypika.terms import AggregateFunction, Field, Function, Parameter
from pypika.utils import format_alias_sql

from tesseract_olap.schema.enums import MemberType


class ClickhouseDataType(Enum):
    """Lists the types of the data the user can expect to find in the associated
    column."""
    BOOLEAN = "Bool"
    DATE = "Date32"
    DATETIME = "DateTime64"
    TIMESTAMP = "UInt32"
    FLOAT32 = "Float32"
    FLOAT64 = "Float64"
    INT8 = "Int8"
    INT16 = "Int16"
    INT32 = "Int32"
    INT64 = "Int64"
    STRING = "String"

    @classmethod
    def from_membertype(cls, mt: MemberType):
        """Transforms a MemberType enum value into a ClickhouseDataType."""
        return next((item for item in cls if item.name == mt.name), cls.STRING)


class ArrayElement(Function):
    def __init__(self, array, n: int, *args, **kwargs) -> None:
        super().__init__("arrayElement", *args, **kwargs)
        self._array = array
        self._n = n

    def get_sql(
        self, with_alias=False, with_namespace=False, quote_char=None, dialect=None, **kwargs
    ) -> str:
        sql = "{name}({array},{n})".format(
            name=self.name,
            array=self._array.get_sql(),
            n=self._n,
        )
        return format_alias_sql(sql, self.alias, **kwargs)


class TopK(AggregateFunction):
    def __init__(
        self,
        amount: int,
        field: Union[str, Field],
        alias: Union[str, None] = None,
    ):
        super().__init__("topK(%d)" % amount, field, alias=alias)


class StringParameter(Parameter):
    """Bracket style with parameter name, e.g. ...WHERE name = {p0}"""

    def get_sql(self, **kwargs) -> str:
        return "{{{0}:String}}".format(self.placeholder)

==> tesseract_olap-0.8.1-py3-none-any.whl: tesseract_olap/backend/clickhouse/dialect.py <==
from enum import Enum
from typing import Union

from pypika.terms import AggregateFunction, Term, Function

from tesseract_olap.schema.enums import MemberType


class ClickhouseDataType(Enum):
    """Lists the types of the data the user can expect to find in the associated
    column."""
    BOOLEAN = "Bool"
    DATE = "Date32"
    DATETIME = "DateTime64"
    TIMESTAMP = "UInt32"
    FLOAT32 = "Float32"
    FLOAT64 = "Float64"
    INT8 = "Int8"
    INT16 = "Int16"
    INT32 = "Int32"
    INT64 = "Int64"
    INT128 = "Int128"
    UINT8 = "UInt8"
    UINT16 = "UInt16"
    UINT32 = "UInt32"
    UINT64 = "UInt64"
    UINT128 = "UInt128"
    STRING = "String"

    @classmethod
    def from_membertype(cls, mt: MemberType):
        """Transforms a MemberType enum value into a ClickhouseDataType."""
        return next((item for item in cls if item.name == mt.name), cls.STRING)


class ArrayElement(Function):
    def __init__(
        self,
        array: Union[str, Term],
        n: Union[int, Term],
        alias: Union[str, None] = None,
    ) -> None:
        super(ArrayElement, self).__init__("arrayElement", array, n, alias=alias)


class Power(Function):
    def __init__(
        self,
        base: Union[int, Term],
        exp: Union[int, Term],
        alias: Union[str, None] = None,
    ):
        super(Power, self).__init__("pow", base, exp, alias=alias)


class AverageWeighted(AggregateFunction):
    def __init__(
        self,
        value_field: Union[str, Term],
        weight_field: Union[str, Term],
        alias: Union[str, None] = None,
    ):
        super().__init__("avgWeighted", value_field, weight_field, alias=alias)


class TopK(AggregateFunction):
    def __init__(
        self,
        amount: int,
        field: Union[str, Term],
        alias: Union[str, None] = None,
    ):
        super().__init__("topK(%d)" % amount, field, alias=alias)
